@@ -1,5 +1,5 @@
 package PAR::Heavy;
-$PAR::Heavy::VERSION = '0.08';
+$PAR::Heavy::VERSION = '0.09';
 
 =head1 NAME
 
@@ -82,7 +82,7 @@ sub _bootstrap {
     }
 
     my $member;
-    $member = PAR::find_par(undef, $file, 1) if defined &PAR::find_par;
+    $member = PAR::_find_par_any(undef, $file, 1) if defined &PAR::_find_par_any;
     return $bootstrap->(@args) unless $member;
 
     $FullCache{$file} = _dl_extract($member, $file);
@@ -127,12 +127,14 @@ sub _dl_extract {
             SUFFIX      => ".$dlext",
             UNLINK      => ($^O ne 'MSWin32'),
         );
+		($filename) = $filename =~ /^([\x20-\xff]+)$/;
     }
     else {
         $filename = File::Spec->catfile(
             ($ENV{PAR_TEMP} || File::Spec->tmpdir),
             ($name || ($member->crc32String . ".$dlext"))
         );
+		($filename) = $filename =~ /^([\x20-\xff]+)$/;
 
         open $fh, '>', $filename or die $!
             unless -r $filename and -e $filename
